@@ -101,7 +101,7 @@ describe 'cinder::api' do
         req_params.merge({'manage_service' => false})
       end
       it 'should not change the state of the service' do
-        is_expected.to contain_service('cinder-api').without_ensure
+        is_expected.to_not contain_service('cinder-api')
       end
       it 'includes cinder::db::sync' do
         is_expected.to contain_class('cinder::db::sync')
@@ -118,18 +118,6 @@ describe 'cinder::api' do
       )}
     end
 
-    context 'while validating the service with default command' do
-      let :params do
-        req_params.merge({
-          :validate => true,
-        })
-      end
-      it { is_expected.to contain_openstacklib__service_validation('cinder-api').with(
-        :command   => 'cinder --os-auth-url http://localhost:5000 --os-project-name services --os-username cinder --os-password foo list',
-        :subscribe => 'Service[cinder-api]',
-      )}
-    end
-
     context 'with a custom auth_strategy' do
       let :params do
         req_params.merge({'auth_strategy' => 'noauth'})
