@@ -38,7 +38,10 @@ describe 'cinder::db::postgresql' do
         }))
       end
 
-      it_behaves_like 'cinder::db::postgresql'
+      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
+      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
+        it_behaves_like 'cinder::db::postgresql'
+      end
     end
   end
 
